/*
 * Code for class reference CHARACTER_32
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ch500.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CHARACTER_32}.code */
EIF_INTEGER_32 F1065_9930 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("code", 1064, Current, 0, 0, 13797);
	RTGC;
	RTHOOK(1);
	Result = (EIF_INTEGER_32) F1065_9931(Current);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {CHARACTER_32}.natural_32_code */
EIF_NATURAL_32 F1065_9931 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("natural_32_code", 1064, Current, 0, 0, 13798);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_NATURAL_32) F1064_9896(Current);
}

/* {CHARACTER_32}.to_character_8 */
EIF_CHARACTER_8 F1065_9932 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("to_character_8", 1064, Current, 0, 0, 13799);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_CHARACTER_8) F1064_9911(Current);
}

void EIF_Minit500 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
